==> flutter_file_view-0.1.1.tar.gz: lib/src/download_util.dart <==
import 'package:flutter/widgets.dart';

import '../flutter_file_view.dart';

///
/// Describe: Download tool class
///
/// @Author: LiWeNHuI
/// @Date: 2021/9/14
///

enum DownloadStatus {
  success,
  fail,
  noPermission,
  serviceErr,
}

class DownloadUtil {
  static Dio _dio() {
    BaseOptions options = BaseOptions(
      connectTimeout: 90 * 1000,
      receiveTimeout: 90 * 1000,
    );
    return new Dio(options);
  }

  ///
  /// Using Dio to realize file download function
  ///
  static Future<DownloadStatus> downloadFile(
    String fileUrl,
    String filePath, {
    ProgressCallback? onReceiveProgress,
  }) async {
    // Request storage permissions
    bool isGranted = await Permission.storage.isGranted;
    if (!isGranted) {
      isGranted = (await Permission.storage.request()).isGranted;
      if (!isGranted) {
        debugPrint("NO Storage Permission");
        return DownloadStatus.noPermission;
      }
    }

    try {
      Response response = await _dio().download(
        fileUrl,
        filePath,
        onReceiveProgress: onReceiveProgress,
      );

      return response.statusCode == 200
          ? DownloadStatus.success
          : DownloadStatus.fail;
    } catch (e) {
      debugPrint('服务器出错或网络连接失败！');
      return DownloadStatus.serviceErr;
    }
  }

  ///
  /// Get file size through network link
  ///
  static Future<String> getFileSize(String fileUrl) async {
    try {
      Response response = await _dio().head(fileUrl);

      int size = 0;
      response.headers.forEach((label, value) {
        if (label == 'content-length') {
          value.forEach((v) {
            size += int.tryParse(v) ?? 0;
          });
        }
      });

      return '文件大小：${filesize(size)}';
    } catch (e) {
      return '文件大小获取失败';
    }
  }
}

==> flutter_file_view-0.1.4.tar.gz: lib/src/download_util.dart <==
import 'package:flutter/widgets.dart';

import '../flutter_file_view.dart';

///
/// Describe: Download tool class
///
/// @Author: LiWeNHuI
/// @Date: 2021/9/14
///

enum DownloadStatus {
  success,
  fail,
  noPermission,
  serviceErr,
}

class DownloadUtil {
  static Dio _dio() {
    BaseOptions options = BaseOptions(
      connectTimeout: 90 * 1000,
      receiveTimeout: 90 * 1000,
    );
    return new Dio(options);
  }

  ///
  /// Using Dio to realize file download function
  ///
  static Future<DownloadStatus> downloadFile(
    String fileUrl,
    String filePath, {
    ProgressCallback? onReceiveProgress,
  }) async {
    // Request storage permissions
    bool isGranted = await Permission.storage.isGranted;
    if (!isGranted) {
      isGranted = (await Permission.storage.request()).isGranted;
      if (!isGranted) {
        debugPrint('NO Storage Permission');
        return DownloadStatus.noPermission;
      }
    }

    try {
      Response response = await _dio().download(
        fileUrl,
        filePath,
        onReceiveProgress: onReceiveProgress,
      );

      return response.statusCode == 200
          ? DownloadStatus.success
          : DownloadStatus.fail;
    } catch (e) {
      debugPrint('服务器出错或网络连接失败！');
      return DownloadStatus.serviceErr;
    }
  }

  ///
  /// Get file size through network link
  ///
  static Future<String> getFileSize(String fileUrl) async {
    try {
      Response response = await _dio().head(fileUrl);

      int size = 0;
      response.headers.forEach((label, value) {
        if (label == 'content-length') {
          value.forEach((v) {
            size += int.tryParse(v) ?? 0;
          });
        }
      });

      return '文件大小：${fileSize(size)}';
    } catch (e) {
      return '文件大小获取失败';
    }
  }
}
